@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: wai-app-static
-version: 3.1.4.1
-id: wai-app-static-3.1.4.1-2771ede2f82f698f69c7f5569f69b185
-key: waiap_9Lthl3aIGLV3M2sc4lRguz
+version: 3.1.5
+id: wai-app-static-3.1.5-c99c41fb98f5790941b5a0bc818346a5
+key: waiap_Bl9PuWbXcgr03Wycv15VAT
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -21,26 +21,24 @@ exposed-modules:
 hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                 WaiAppStatic.Storage.Embedded.TH
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-app-static-3.1.4.1
-hs-libraries: HSwai-app-static-3.1.4.1-9Lthl3aIGLV3M2sc4lRguz
+import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.5
+library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.5
+data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-app-static-3.1.5
+hs-libraries: HSwai-app-static-3.1.5-Bl9PuWbXcgr03Wycv15VAT
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
-    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
-    cryptohash-conduit-0.1.1-9cd42855330eec21f69d5ac4f36d7158
+    cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     http-date-0.0.6.1-757f4a31bc2dcd5d0b4e75509958696c
     http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
+    memory-0.11-3a745e41fe78387f608c420e9b455d25
     mime-types-0.1.0.6-7d5f22022675c00ea07fd0f1df020c2e
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
     optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
@@ -50,9 +48,9 @@ depends:
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
-    wai-extra-3.0.15-954ac840c460f6e3c2fb191ca01c5fce
-    warp-3.2.3-6de819de378ae4c57281b63b66004254
+    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
+    wai-extra-3.0.15-2f88b45989ced36024c3ff3943866d23
+    warp-3.2.4-afffa286f2a73716d3c875d3f70e8c61
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
 haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
 haddock-html: /usr/share/doc/haskell-wai-app-static/html
